﻿--[[
    Aura Filter
    A table of spellIDs to create icons for.
    To add spellIDs, look up a spell on www.wowhead.com and look at the URL:
    https://classic.wowhead.com/spell=SPELLID
    https://cn.classic.wowhead.com/spell=SPELLID
--]]

local _, ns = ...
local filter = {}
local ORD = ns.oUF_RaidDebuffs or _G.oUF_RaidDebuffs

local function Defaults(priorityOverride)
	return {
		enable = true,
		priority = priorityOverride or 0,
		stackThreshold = 0
	}
end

filter = {
    Auras = {
    -- Faction Racial
        [7744]  = true, -- Will of the Forsaken    -- 亡灵意志 - Undead
        [23234] = true, -- Blood Fury              -- 血性狂暴 - Orc
        [20594] = true, -- Stoneform               -- 石像形态 - Dwarf
        [20600] = true, -- Perception              -- 感知 - Human
        [26635] = true, -- Berserking              -- 狂暴 - Troll
        
    -- Warrior
        [871]   = true, -- Shield Wall             -- 盾墙
        [1719]  = true, -- Recklessness            -- 鲁莽
        [12328] = true, -- Death Wish              -- 死亡之愿
        [12975] = true, -- Last Stand              -- 破釜沉舟
        [18499] = true, -- Berserker Rage          -- 狂暴之怒
        [20230] = true, -- Retaliation             -- 反击风暴
        
    -- Warlock
        [710]   = true, -- Banish                  -- 放逐术 (Rank 1)
        [18647] = true, -- Banish                  -- 放逐术 (Rank 2)
        [17800] = true, -- Shadow Vulnerability    -- 暗影易伤
        [11740] = true, -- Shadow Ward             -- 暗影防护结界 (Rank 3)
        [28610] = true, -- Shadow Ward             -- 暗影防护结界 (Rank 4)
        [19443] = true, -- Sacrifice               -- 牺牲 (Rank 6)
        [17730] = true, -- Major Spellstone        -- 特效法术石
        [17941] = true, -- Shadow Trance           -- 夜幕降临
        [18288] = true, -- Amplify Curse           -- 诅咒增幅
        [18708] = true, -- Fel Domination          -- 恶魔支配
        [24259] = true, -- Spell Lock              -- 法术锁定

    -- Priest
        [10890] = true, -- Psychic Scream          -- 心灵尖啸 (Rank 4)
        [15487] = true, -- Silence                 -- 沉默
        [6346]  = true, -- Fear Ward               -- 防护恐惧结界
        [10901] = true, -- Power Word: Shield      -- 真言术：盾 (Rank 10)
        [10929] = true, -- Renew                   -- 恢复 (Rank 9)
        [25315] = true, -- Renew                   -- 恢复 (Rank 10)
        [10942] = true, -- Fade                    -- 渐隐术 (Rank 6)
        [10060] = true, -- Power Infusion          -- 能量灌注

    -- Rogue
        [1330]  = true, -- Garrote - Silence       -- 锁喉沉默
        [1833]  = true, -- Cheap Shot              -- 偷袭
        [2094]  = true, -- Blind                   -- 致盲
        [8643]  = true, -- Kidney Shot             -- 肾击 (Rank 2)
        [6774]  = true, -- Slice and Dice          -- 切割 (Rank 2)
        [5277]  = true, -- Evasion                 -- 闪避
        [11305] = true, -- Sprint                  -- 疾跑 (Rank 3)
        [13750] = true, -- Adrenaline Rush         -- 冲动
        [13877] = true, -- Blade Flurry            -- 剑刃乱舞
        [14177] = true, -- Cold Blood              -- 冷血

    -- MAGE
        [12826] = true, -- Polymorph               -- 变形术
        [28271] = true, -- Polymorph: Turtle       -- 变形术:龟
        [28272] = true, -- Polymorph: Pig          -- 变形术:猪
        [130]   = true, -- Slow Fall               -- 缓落术
        [10225] = true, -- Fire Ward               -- 火焰防护结界 (Rank 5)
        [28609] = true, -- Frost Ward              -- 冰霜防护结界 (Rank 5)
        [10193] = true, -- Mana Shield             -- 法力护盾 (Rank 6)
        [13033] = true, -- Ice Barrier             -- 寒冰护体 (Rank 4)
        [11958] = true, -- Ice Block               -- 寒冰屏障
        [12042] = true, -- Arcane Power            -- 奥术强化
        [12043] = true, -- Presence of Mind        -- 气定神闲
        [12536] = true, -- Clearcasting            -- 节能施法
        [28682] = true, -- Combustion              -- 燃烧
        [22008] = true, -- Netherwind Focus        -- 灵风专注

    -- Hunter
        [14309] = true, -- Freezing Trap Effect    -- 冰冻陷阱效果 (Rank 3)
        [19503] = true, -- Scatter Shot            -- 驱散射击
        [3045]  = true, -- Rapid Fire              -- 急速射击
        [5384]  = true, -- Feign Death             -- 假死
        [19263] = true, -- Deterrence              -- 威慑      

    -- Druid
        [2893]  = true, -- Abolish Poison          -- 驱毒术
        [9821]  = true, -- Dash                    -- 急奔 (Rank 2)
        [9841]  = true, -- Rejuvenation            -- 回春术 (Rank 10)
        [25299] = true, -- Rejuvenation            -- 回春术 (Rank 11)
        [9858]  = true, -- Regrowth                -- 愈合 (Rank 9)
        [16870] = true, -- Clearcasting            -- 节能施法
        [16886] = true, -- Nature's Grace          -- 自然之赐
        [17116] = true, -- Nature's Swiftness      -- 自然迅捷
        [22812] = true, -- Barkskin                -- 树皮术
        [22842] = true, -- Frenzied Regeneration   -- 狂暴回复
        [29166] = true, -- Innervate               -- 激活

    -- PALADIN
        [1020]  = true, -- Divine Shield           -- 圣盾术
        [1038]  = true, -- Blessing of Salvation   -- 拯救祝福
        [1044]  = true, -- Blessing of Freedom     -- 自由祝福
        [10278] = true, -- Blessing of Protection  -- 保护祝福 (Rank 3)
        [20729] = true, -- Blessing of Sacrifice   -- 牺牲祝福 (Rank 2)
        [19753] = true, -- Divine Intervention     -- 神圣干涉

    -- Shaman
        [8178]  = true, -- Grounding Totem Effect  -- 根基图腾效果
        [16188] = true, -- Nature's Swiftness      -- 自然迅捷
        [17360] = true, -- Mana Tide               -- 法力之潮
        [17364] = true, -- Stormstrike             -- 风暴打击

    -- Items
        [2379]  = true, -- Speed                   -- 迅捷药水
        [5024]  = true, -- Flee                    -- 末日颅骨
        [3169]  = true, -- Invulnerability         -- 有限无敌药水
        [6615]  = true, -- Free Action             -- 自由行动药水
        [23271] = true, -- Ephemeral Power         -- 短暂能量护符
        [23782] = true, -- Gift of Life            -- 生命赐福
        [24575] = true, -- Brittle Armor           -- 脆弱护甲
        [24659] = true, -- Unstable Power          -- 能量无常
        [24662] = true, -- Restless Strength       -- 充沛之力
        [21165] = true, -- Empyrean Demolisher     -- 苍穹击碎者
        [13181] = true, -- Gnomish Mind Control Cap         -- 侏儒洗脑帽
        [17543] = true, -- Greater Fire Protection Potion   -- 强效火焰防护药水
        [17544] = true, -- Greater Frost Protection Potion  -- 强效冰霜防护药水
        [17546] = true, -- Greater Nature Protection Potion -- 强效自然防护药水
        [17548] = true, -- Greater Shadow Protection Potion -- 强效暗影防护药水
        [17549] = true, -- Greater Arcane Protection Potion -- 强效奥术防护药水
    },

    RaidDebuffs = {
    -- Global
        [6788]  = Defaults(),  -- Weakened Soul         -- 虚弱灵魂
        [25771] = Defaults(),  -- Forbearance           -- 自律
        [8326]  = Defaults(),  -- Ghost                 -- 鬼魂
        [15007] = Defaults(),  -- Resurrection Sickness -- 复活虚弱

    -- Items
        [13181] = Defaults(5), -- Gnomish Mind Control Cap -- 侏儒洗脑帽

    -- Onyxia 奥妮克希亚
        [18431] = Defaults(2), -- Bellowing Roar        -- 低沉咆哮

    -- Molten Core 熔火之心
        [19771] = Defaults(2), -- Serrated Bite         -- 尖牙撕咬
        [19364] = Defaults(2), -- Ground Stomp          -- 大地践踏
        [19393] = Defaults(2), -- Soul Burn             -- 灵魂燃烧
        [19641] = Defaults(2), -- Pyroclast Barrage     -- 火屑弹幕
        [19702] = Defaults(2), -- Impending Doom        -- 末日降临
        [19703] = Defaults(2), -- Lucifron's Curse      -- 鲁西弗隆的诅咒
        [19408] = Defaults(2), -- Panic                 -- 恐慌
        [19716] = Defaults(2), -- Gehennas' Curse       -- 基赫纳斯的诅咒
        [20277] = Defaults(2), -- Fist of Ragnaros      -- 拉格纳罗斯之拳
        [19496] = Defaults(2), -- Magma Shackles        -- 熔岩镣铐
        [19659] = Defaults(6), -- Ignite Mana           -- 点燃法力
        [20475] = Defaults(6), -- Living Bomb           -- 活化炸弹
        [19713] = Defaults(2), -- Shazzrah's Curse      -- 沙斯拉尔的诅咒

    -- Blackwing Lair 黑翼之巢
        [23023] = Defaults(2), -- Conflagration         -- 燃烧
        [18173] = Defaults(2), -- Burning Adrenaline    -- 燃烧刺激
        [23620] = Defaults(2), -- Burning Adrenaline    -- 燃烧刺激
        [24573] = Defaults(2), -- Mortal Strike         -- 致死打击
        [23341] = Defaults(2), -- Flame Buffet          -- 烈焰打击
        [23340] = Defaults(2), -- Shadow of Ebonroc     -- 埃博诺克之影
        [23170] = Defaults(2), -- Bronze                -- 龙血之痛：青铜
        [23171] = Defaults(3), -- Time Stop             -- 时间停止
        [22686] = Defaults(2), -- Bellowing Roar        -- 低沉咆哮
        [23603] = Defaults(2), -- Wild Polymorph        -- 狂野变形
        [23402] = Defaults(2), -- Corrupted Healing     -- 堕落治疗
        [22687] = Defaults(2), -- Veil of Shadow        -- 暗影迷雾

    -- Zul'Gurub 祖尔格拉布
        [13704] = Defaults(2), -- Psychic Scream        -- 心灵尖啸
        [16508] = Defaults(2), -- Intimidating Roar     -- 破胆咆哮
        [22884] = Defaults(2), -- Psychic Scream        -- 心灵尖啸
        [23918] = Defaults(2), -- Sonic Burst           -- 音爆
        [23860] = Defaults(2), -- Holy Fire             -- 神圣之火
        [24099] = Defaults(2), -- Poison Bolt Volley    -- 毒箭之雨
        [24111] = Defaults(2), -- Corrosive Poison      -- 腐蚀之毒
        [24317] = Defaults(2), -- Sunder Armor          -- 破甲
        [16856] = Defaults(2), -- Mortal Strike         -- 致死打击
        [24314] = Defaults(2), -- Threatening Gaze      -- 威慑凝视
        [22666] = Defaults(2), -- Silence               -- 沉默
        [21060] = Defaults(2), -- Blind                 -- 致盲
        [22859] = Defaults(2), -- Mortal Cleave         -- 致死顺劈
        [24210] = Defaults(2), -- Mark of Arlokk        -- 娅尔罗的印记
        [24053] = Defaults(2), -- Hex                   -- 妖术
        [24261] = Defaults(2), -- Brain Wash            -- 洗脑
        [24306] = Defaults(2), -- Delusions of Jin'do   -- 金度的欺骗
        [24327] = Defaults(3), -- Cause Insanity        -- 疯狂
        [24328] = Defaults(2), -- Corrupted Blood       -- 堕落之血

    -- Ruins of Ahn'Qiraj 安其拉废墟
        [25656] = Defaults(2), -- Sand Trap             -- 沙漠陷阱
        [25646] = Defaults(2), -- Mortal Wound          -- 重伤
        [25471] = Defaults(2), -- Attack Order          -- 攻击命令
        [96]    = Defaults(2), -- Dismember             -- 肢解
        [25371] = Defaults(2), -- Consume               -- 吞噬
        [25725] = Defaults(2), -- Paralyze              -- 麻痹
        [22997] = Defaults(2), -- Plague                -- 瘟疫
        [25189] = Defaults(2), -- Enveloping Winds      -- 包围之风
        
    -- Temple of Ahn'Qiraj 安其拉神殿
        [785]   = Defaults(2), -- True Fulfillment      -- 充实
        [1121]  = Defaults(2), -- Entangle              -- 纠缠
        [25646] = Defaults(2), -- Mortal Wound          -- 重伤
        [25989] = Defaults(2), -- Toxin                 -- 剧毒
        [26050] = Defaults(2), -- Acid Spit             -- 酸性喷射
        [26053] = Defaults(2), -- Noxious Poison        -- 致命剧毒
        [26079] = Defaults(2), -- Cause Insanity        -- 导致疯狂
        [26102] = Defaults(2), -- Sand Blast            -- 沙尘爆裂
        [26143] = Defaults(2), -- Mind Flay             -- 精神鞭笞
        [26180] = Defaults(2), -- Wyvern Sting          -- 翼龙钉刺
        [26476] = Defaults(2), -- Digestive Acid        -- 消化酸液
        [26556] = Defaults(2), -- Plague                -- 瘟疫
        [26580] = Defaults(2), -- Fear                  -- 恐惧
        [26607] = Defaults(2), -- Blizzard              -- 暴风雪
        [26613] = Defaults(2), -- Unbalancing Strike    -- 重压打击

    -- Naxxramas 纳克萨玛斯
        [27993] = Defaults(2), -- Stomp                 -- 践踏
        [28350] = Defaults(2), -- Veil of Darkness      -- 黑暗之雾
        [28440] = Defaults(2), -- Veil of Shadow        -- 幽影之雾
        [28431] = Defaults(2), -- Poison Charge         -- 毒性充能
        [28732] = Defaults(2), -- Widow's Embrace       -- 黑女巫的拥抱
        [28796] = Defaults(2), -- Poison Bolt Volley    -- 毒箭之雨
        [28776] = Defaults(2), -- Necrotic Poison       -- 死灵之毒
        [28622] = Defaults(2), -- Web Wrap          	-- 蛛网裹体
        [29484] = Defaults(2), -- Web Spray             -- 蛛网喷射
        [29213] = Defaults(2), -- Curse of the Plaguebringer -- 瘟疫使者的诅咒
        [29212] = Defaults(2), -- Cripple               -- 残废术
        [29998] = Defaults(2), -- Decrepit Fever        -- 衰弱瘟疫
        [29204] = Defaults(2), -- Inevitable Doom       -- 必然的厄运
        [28832] = Defaults(2), -- Mark of Korth'azz     -- 库尔塔兹印记
        [28833] = Defaults(2), -- Mark of Blaumeux      -- 布劳缪克丝印记
        [28834] = Defaults(2), -- Mark of Mograine      -- 莫格莱尼印记
        [28835] = Defaults(2), -- Mark of Zeliek	    -- 瑟里耶克印记
        [28169] = Defaults(2), -- Mutating Injection	-- 变异注射
        [28062] = Defaults(2), -- Positive Charge       -- 正能量
        [28085] = Defaults(2), -- Negative Charge       -- 负能量
        [28542] = Defaults(2), -- Life Drain            -- 生命吸取
        [28522] = Defaults(2), -- Icebolt               -- 寒冰箭
        [27808] = Defaults(2), -- Frost Blast	        -- 冰霜冲击
        [28410] = Defaults(2), -- Chains of Kel'Thuzad	-- 克尔苏加德的锁链
        [27819] = Defaults(2), -- Detonate Mana         -- 自爆法力

    -- PvP -- 
    -- Warrior
        [5246]  = Defaults(4), -- Intimidating Shout    -- 破胆怒吼
        [7373]  = Defaults(2), -- Hamstring             -- 断筋
        [23694] = Defaults(3), -- Improved Hamstring    -- 强化断筋
        [12323] = Defaults(2), -- Piercing Howl         -- 刺耳怒吼
        [20617] = Defaults(3), -- Intercept             -- 拦截 (Rank 3)
        [21553] = Defaults(1), -- Mortal Strike         -- 致死打击 (Rank 4)
        [12809] = Defaults(3), -- Concussion Blow       -- 震荡猛击
        
    -- Warlock
        [5782]  = Defaults(3), -- Fear                  -- 恐惧术 (Rank 1)
        [6213]  = Defaults(3), -- Fear                  -- 恐惧术 (Rank 2)
        [6215]  = Defaults(3), -- Fear                  -- 恐惧术 (Rank 3)
        [6358]  = Defaults(3), -- Seduction             -- 魅惑
        [11719] = Defaults(3), -- Curse of Tongues      -- 语言诅咒
        [17926] = Defaults(5), -- Death Coil            -- 死亡缠绕
        [17928] = Defaults(3), -- Howl of Terror        -- 恐惧嚎叫
        [11668] = Defaults(1), -- Immolate              -- 献祭 (Rank 7)
        [25309] = Defaults(1), -- Immolate              -- 献祭 (Rank 8)
        [11672] = Defaults(1), -- Corruption            -- 腐蚀术 (Rank 6)
        [25311] = Defaults(1), -- Corruption            -- 腐蚀术 (Rank 7)

    -- Priest
        [10890] = Defaults(3), -- Psychic Scream        -- 心灵尖啸
        [10912] = Defaults(5), -- Mind Control          -- 精神控制
        [15487] = Defaults(3), -- Silence               -- 沉默
        [15269] = Defaults(3), -- Blackout              -- 昏阙
        [10894] = Defaults(1), -- Shadow Word: Pain     -- 暗言术：痛 (Rank 8)
        
    -- Rogue
        [1833]  = Defaults(3), -- Cheap Shot            -- 偷袭
        [2094]  = Defaults(5), -- Blind                 -- 致盲
        [8643]  = Defaults(4), -- Kidney Shot           -- 肾击
        [11297] = Defaults(4), -- Sap                   -- 闷棍 (Rank 3)
        [11286] = Defaults(2), -- Gouge                 -- 凿击 (Rank 5)
        [11201] = Defaults(3), -- Crippling Poison      -- 致残毒药 (Rank 2)
        [11398] = Defaults(3), -- Mind-numbing Poison III -- 麻痹毒药 III
        
    -- Mage
        [116]	= Defaults(2), -- Frostbolt             -- 寒冰箭 (Rank 1)
        [10181]	= Defaults(2), -- Frostbolt             -- 寒冰箭 (Rank 10)
		[25304]	= Defaults(2), -- Frostbolt             -- 寒冰箭 (Rank 11)
        [12826] = Defaults(3), -- Polymorph             -- 变形术 (Rank 4)
        [28271] = Defaults(3), -- Polymorph: Turtle     -- 变形术:龟
        [28272] = Defaults(3), -- Polymorph: Pig        -- 变形术:猪
        [10161] = Defaults(2), -- Cone of Cold          -- 冰锥术 (Rank 5)
        [122]   = Defaults(4), -- Frost Nova            -- 冰霜新星 (Rank 1)
        [865]   = Defaults(4), -- Frost Nova            -- 冰霜新星 (Rank 2)
        [6131]  = Defaults(4), -- Frost Nova            -- 冰霜新星 (Rank 3)
        [10230] = Defaults(4), -- Frost Nova            -- 冰霜新星 (Rank 4)
        [12494] = Defaults(4), -- Frostbite             -- 霜寒刺骨
        [18469] = Defaults(5), -- Counterspell Silenced -- 法术反制 -沉默
        
    -- Hunter
        [1543]  = Defaults(2), -- Flare                 -- 照明弹
        [5116]  = Defaults(2), -- Concussive Shot       -- 震荡射击
        [14280] = Defaults(2), -- Viper Sting           -- 蝰蛇钉刺
        [14309] = Defaults(3), -- Freezing Trap         -- 冰冻陷阱
        [14325] = Defaults(1), -- Hunter's Mark         -- 猎人印记 (Rank 4)
        [19185] = Defaults(3), -- Entrapment            -- 诱捕
        [14268] = Defaults(2), -- Wing Clip             -- 摔绊 (Rank 3)
        [19229] = Defaults(3), -- Improved Wing Clip    -- 强化摔绊
        [19503] = Defaults(3), -- Scatter Shot          -- 驱散射击
        [20910] = Defaults(3), -- Counterattack         -- 反击 (Rank 3)
        [13555] = Defaults(1), -- Serpent Sting         -- 毒蛇钉刺 (Rank 8)
        [25295] = Defaults(1), -- Serpent Sting         -- 毒蛇钉刺 (Rank 9)

    -- Druid
        [9907]  = Defaults(5), -- Faerie Fire           -- 精灵之火
        [17392] = Defaults(5), -- Faerie Fire (Feral)   -- 精灵之火（野性）
        [9853]  = Defaults(2), -- Entangling Roots      -- 纠缠根须
        [8983]  = Defaults(3), -- Bash                  -- 重击
        [9827]  = Defaults(2), -- Pounce                -- 突袭
        [19675] = Defaults(3), -- Feral Charge Effect   -- 野性冲锋效果
        
    -- Paladin
        [10308] = Defaults(4), -- Hammer of Justice     -- 制裁之锤
        [20066] = Defaults(3), -- Repentance            -- 忏悔

    -- Shaman
        [2484]  = Defaults(1), -- Earthbind Totem       -- 地缚图腾
        [10473] = Defaults(1), -- Frost Shock           -- 冰霜震击

    --  Alterac Valley 奥特兰克山谷
        [13323] = Defaults(1), -- Polymorph             -- 变形术
        [19137] = Defaults(1), -- Slow                  -- 减速术
        [15588] = Defaults(1), -- Thunderclap           -- 雷霆一击
        [19136] = Defaults(2), -- Stormbolt             -- 风暴之锤
        [22127] = Defaults(1), -- Entangling Roots      -- 纠缠根须
    },

    AuraWatch = {
        ['ALL'] = {
            {   3169,   'TOPRIGHT', 0,  0,  true,   1   }, -- Invulnerability               -- 有限无敌药水
            {   6615,   'TOPRIGHT', 0,  0,  true,   1   }, -- Free Action                   -- 自由行动药水
            {   301089, 'TOPRIGHT', 0,  0,  true,   1   }, -- Horde Flag                    -- 部落旗帜
            {   301091, 'TOPRIGHT', 0,  0,  true,   1   }, -- Alliance Flag                 -- 联盟旗帜
        },
        ['WARRIOR'] = {
            {   11551,      'BOTTOMRIGHT'               }, -- Battle Shout                  -- 战斗怒吼 (Rank 6)
            {   25289,      'BOTTOMRIGHT'               }, -- Battle Shout                  -- 战斗怒吼 (Rank 7)
        },
        ['PRIEST'] = {
            {   10901,      'CENTER'                    }, -- Power Word: Shield            -- 真言术：盾 (Rank 10)
            {   10060,      'TOP'                       }, -- Power Infusion                -- 能量灌注
            {   10929,      'TOPRIGHT'                  }, -- Renew                         -- 恢复 (Rank 9)
            {   25315,      'TOPRIGHT'                  }, -- Renew                         -- 恢复 (Rank 10)
            {   10938,      'TOPRIGHT',     -12,    0   }, -- Power Word: Fortitude         -- 真言术：韧 (Rank 6)
            {   21564,      'TOPRIGHT',     -12,    0   }, -- Prayer of Fortitude           -- 坚韧祷言 (Rank 2)
            {   27841,      'BOTTOMRIGHT'               }, -- Divine Spirit                 -- 神圣之灵 (Rank 4)
            {   27681,      'BOTTOMRIGHT'               }, -- Prayer of Spirit              -- 精神祷言
            {   10958,      'BOTTOMRIGHT',  -12,    0   }, -- Shadow Protection             -- 防护暗影 (Rank 3)
            {   27683,      'BOTTOMRIGHT',  -12,    0   }, -- Prayer of Shadow Protection   -- 暗影防护祷言
        },
        ['DRUID'] = {
            {   29166,      'CENTER'                    }, -- Innervate                     -- 激活
            {   2893,       'TOP'                       }, -- Abolish Poison                -- 驱毒术
            {   774,        'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 1)
            {   1058,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 2)
            {   1430,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 3)
            {   2090,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 4)
            {   2091,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 5)
            {   3627,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 6)
            {   8910,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 7)
            {   9839,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 8)
            {   9840,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 9)
            {   9841,       'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 10)
            {   25299,      'TOPRIGHT'                  }, -- Rejuvenation                  -- 回春术 (Rank 11)
            {   8936,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 1)
            {   8938,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 2)
            {   8939,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 3)
            {   8940,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 4)
            {   8941,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 5)
            {   9750,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 6)
            {   9856,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 7)
            {   9857,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 8)
            {   9858,       'TOPRIGHT',     -12,    0   }, -- Regrowth                      -- 愈合 (Rank 9)
            {   9885,       'BOTTOMRIGHT'               }, -- Mark of the Wild              -- 野性印记 (Rank 7)
            {   21850,      'BOTTOMRIGHT'               }, -- Gift of the Wild              -- 野性赐福 (Rank 2)
            {   9910,       'BOTTOMRIGHT',  -12,    0   }, -- Thorns                        -- 荆棘术 (Rank 6)
        },
        ['PALADIN'] = {
            {   1044,       'CENTER'                    }, -- Blessing of Freedom	        -- 自由祝福
            {   20729,      'CENTER'                    }, -- Blessing Sacrifice	        -- 牺牲祝福 (Rank 2)
            {   10278,      'CENTER'                    }, -- Blessing of Protection        -- 保护祝福 (Rank 3)
            {   19752,      'TOP'                       }, -- Divine Intervention	        -- 神圣干涉
            {   19979,      'TOP'   		            }, -- Blessing of Light		        -- 光明祝福 (Rank 3)
            {   20217,      'TOPRIGHT'                  }, -- Blessing of Kings             -- 王者祝福
            {   25898,      'TOPRIGHT'                  }, -- Greater Blessing of Kings     -- 强效王者祝福
            {   25291,      'BOTTOMRIGHT'               }, -- Blessing of Might		        -- 力量祝福 (Rank 7)
            {   25916,      'BOTTOMRIGHT'               }, -- Greater Blessing of Might     -- 强效力量祝福 (Rank 2)
            {   25290,      'BOTTOMRIGHT'               }, -- Blessing of Wisdom	        -- 智慧祝福 (Rank 6)
            {   25918,      'BOTTOMRIGHT'               }, -- Greater Blessing of Wisdom    -- 强效智慧祝福 (Rank 2)
            {   1038,       'BOTTOMRIGHT',  -12,    0   }, -- Blessing of Salvation	        -- 拯救祝福
            {   25895,      'BOTTOMRIGHT',  -12,    0   }, -- Greater Blessing of Salvation -- 强效拯救祝福
        },
        ['SHAMAN'] = {
            {   17360,      'CENTER'                    }, -- Mana Tide                     -- 法力之潮图腾 (Rank 3)
            {   16237,      'TOPRIGHT'                  }, -- Ancestral Fortitude           -- 先祖坚韧 (Rank 3)
            {   29203,      'TOPRIGHT',     -12,    0   }, -- Healing Way                   -- 治疗之道
            {   10405,      'BOTTOMRIGHT'               }, -- Stoneskin Totem               -- 石肤术 (Rank 6)
            {   25527,      'BOTTOMRIGHT'               }, -- Strength of Earth             -- 大地之力 (Rank 6)
            {   10461,      'BOTTOMRIGHT',  -12,    0   }, -- Healing Stream                -- 治疗之泉 (Rank 5)
            {   10494,      'BOTTOMRIGHT',  -12,    0   }, -- Mana Spring                   -- 法力之泉 (Rank 4)
            {   10535,      'BOTTOMRIGHT',  -12,    0   }, -- Fire Resistance Totem         -- 火焰抗性 (Rank 3)
            {   8178,       'TOP'                       }, -- Grounding Totem Effect        -- 根基图腾效果
            {   25909,      'TOP'                       }, -- Tranquil Air                  -- 宁静之风
            {   25360,      'TOP'                       }, -- Grace of Air                  -- 风之优雅 (Rank 3)
            {   10599,      'TOP'                       }, -- Nature Resistance Totem       -- 自然抗性 (Rank 3)
            {   15110,      'TOP'                       }, -- Windwall                      -- 风墙 (Rank 3)
            {   10477,      'BOTTOM'                    }, -- Frost Resistance Totem        -- 冰霜抗性图腾 (Rank 3)
        },
        ['MAGE'] = {
            {   10174,      'TOPRIGHT'                  }, -- Dampen Magic                  -- 魔法抑制 (Rank 5)
            {   10170,      'TOPRIGHT'                  }, -- Amplify Magic                 -- 魔法增效 (Rank 4)
            {   10157,      'BOTTOMRIGHT'               }, -- Arcane Intellect              -- 奥术智慧 (Rank 5)
            {   23028,      'BOTTOMRIGHT'               }, -- Arcane Brilliance             -- 奥术光辉 (Rank 1)
        },
        ['WARLOCK'] = {
            {   20707,      'CENTER'    	            }, -- Soulstone Resurrection        -- 灵魂石复活 (Rank 1)
            {   20762,      'CENTER'    	            }, -- Soulstone Resurrection        -- 灵魂石复活 (Rank 2)
            {   20763,      'CENTER'    	            }, -- Soulstone Resurrection        -- 灵魂石复活 (Rank 3)
            {   20764,      'CENTER'    	            }, -- Soulstone Resurrection        -- 灵魂石复活 (Rank 4)
            {   20765,      'CENTER'    	            }, -- Soulstone Resurrection        -- 灵魂石复活 (Rank 5)
            {   11743,      'TOPRIGHT'    	            }, -- Detect Greater Invisibility   -- 侦测强效隐形
            {   5697,       'TOPRIGHT',     -12,    0   }, -- Unending Breath               -- 水下呼吸
            {   11767,      'BOTTOMRIGHT'               }, -- Blood Pact                    -- 血之契印 (Rank 5)
            {   19480,      'BOTTOMRIGHT',  -12,    0   }, -- Paranoia                      -- 多疑
        },
        ['HUNTER'] = {
            {   13159,      'TOPRIGHT'                  }, -- Aspect of the Pack            -- 豹群守护
            {   20906,      'BOTTOMRIGHT'               }, -- Trueshot Aura                 -- 强击光环 (Rank 3)
            {   20190,      'BOTTOMRIGHT',  -12,    0   }, -- Aspect of the Wild            -- 野性守护 (Rank 2)
        },
        ['ROGUE'] = {},
    },
    
    Frenzy = {
        [GetSpellInfo(19451)] = true, -- Molten Core          -- Magmadar            -- 玛格曼达
        [GetSpellInfo(22428)] = true, -- Blackwing Lair       -- Death Talon Seether -- 死爪狂乱者
        [GetSpellInfo(23342)] = true, -- Blackwing Lair       -- Flamegor            -- 费尔默
        [GetSpellInfo(23128)] = true, -- Blackwing Lair       -- Chromaggus          -- 克洛玛古斯
        [GetSpellInfo(24689)] = true, -- Zul'Gurub            -- High Priest Thekal  -- 高阶祭司塞卡尔
        [GetSpellInfo(26041)] = true, -- Temple of Ahn'Qiraj  -- Qiraji Slayer       -- 其拉执行者
        [GetSpellInfo(26051)] = true, -- Temple of Ahn'Qiraj  -- Princess Huhuran    -- 哈霍兰公主
        [GetSpellInfo(28371)] = true, -- Naxxramas            -- Gluth               -- 格拉斯
    },
}

ORD:RegisterDebuffs(filter.RaidDebuffs)
-----------------------------
-- Hand over --
-----------------------------
ns.filter = filter