﻿local _, ns = ...
local cfg = CreateFrame('Frame')
local mediaFolder = 'Interface\\AddOns\\oUF_Nihlathak\\Media\\'

--------------
-- ReloadUI --
--------------
SLASH_RELOADUI1 = '/rl'
SlashCmdList.RELOADUI = ReloadUI

------------
-- Border --
------------
	cfg.frameBD = {
	   edgeFile = mediaFolder..'glowTex', edgeSize = 3,
	}
	cfg.pixelBD = {
	   edgeFile = [[Interface\Buttons\WHITE8x8]], edgeSize = 1,
	   bgFile   = [[Interface\ChatFrame\ChatFrameBackground]],
	   insets   = {top = 1, left = 1, bottom = 1, right = 1},
	}

------------
-- Colors --
------------
	cfg.maincolor  = {	20/255,		20/255,		20/255	}	-- main color: health bar and aura overlay color
	cfg.hpBGcolor  = {	255/255, 	255/255, 	255/255	}	-- health bar background color
	cfg.pbBGcolor  = {	40/255,		40/255, 	40/255	}	-- power bar background color
	cfg.timecolor  = {	38/255, 	229/255, 	255/255	}	-- aura timer text color
	cfg.countcolor = {	255/255, 	209/255, 	0/255	}	-- aura count text color
	cfg.SelfColor  = {	38/255, 	255/255, 	38/255	}	-- HealComm Self color
	cfg.OtherColor = {	255/255, 	255/255, 	0/255	}	-- HealComm Other color

-----------	
-- Media --
-----------
	-- Texture
	cfg.Normal   = mediaFolder..'Normal'			-- health/power bar texture
	cfg.NormBG   = mediaFolder..'NormalBG'			-- health/power bar background texture
	cfg.Castbar  = mediaFolder..'Castbar'			-- cast bar texture
	cfg.Healbar  = mediaFolder..'Healbar'			-- HealPrediction bar texture
	cfg.Auratex  = mediaFolder..'Auratex'			-- border texture for auras
	cfg.Arrow	 = mediaFolder..'Arrow'				-- player's health bar arrow texture

	-- Font
	cfg.NameFont = mediaFolder..'NameF.ttf'			-- font used for name
	cfg.NumbFont = mediaFolder..'NumbF.ttf'			-- font used for bar number
	cfg.AuraFont = mediaFolder..'AuraF.ttf'			-- font used for aura time
	cfg.PlugFont = mediaFolder..'PlugF.ttf'			-- font used for status number
	cfg.CurrFont = mediaFolder..'CurrF.ttf'			-- font used for current number

	cfg.SmallFS  = 10								-- small font size
	cfg.NormFS   = 12								-- normal font size
	cfg.LargeFS  = 14								-- large font size	
	cfg.FontF    = 'OUTLINE'						-- Font Flag, can be: 'OUTLINE', 'THICKOUTLINE' and 'MONOCHROME' or nil (no outline)

	-- Elements Texture
	cfg.Afk		 = mediaFolder..'afk'				-- AFK icon texture
	cfg.Dnd  	 = mediaFolder..'dnd'				-- DND icon texture
	cfg.Cit  	 = mediaFolder..'combat'			-- Combat icon texture
	cfg.Lit  	 = mediaFolder..'leader'			-- Leader icon texture
	cfg.MLi  	 = mediaFolder..'looter'			-- Master Looter icon texture
	cfg.Rit  	 = mediaFolder..'rested'			-- Resting icon texture
	cfg.RTi  	 = mediaFolder..'raidicon'			-- RaidTarget icon texture
	cfg.movH 	 = mediaFolder..'movlight'			-- mouseover highlight texture
	cfg.thdH 	 = mediaFolder..'threat'			-- threat debuff highlight texture
	cfg.CPt 	 = mediaFolder..'CPoints'			-- Combo Points texture

----------------------
-- General Settings --
----------------------
	-- Portrait
	cfg.pAlpha 		= 0.4							-- portrait alpha
	cfg.delay  		= 1.5							-- delay seconds of portrait xprep fade-in-out 

	-- Auras
	cfg.forceShow	= false							-- force show unit frame auras
	cfg.hideCDs		= true							-- hide CD spiral
	cfg.hideOcc		= true							-- hide OmniCC CDs
	cfg.hideCDc		= true							-- hide CooldownCount
	cfg.auraSize	= 24							-- aura size
	cfg.auraSizeP	= 20							-- aura size for party
	cfg.auraTimer	= 600							-- hidden if an aura has remaining time greater than this
	cfg.auraZoom	= 1.2							-- aura size on mouseover

	-- MT MA Party Raid Frame
	cfg.MTMAFrame	= true							-- show main tank/assist frame, can be set via /mt /ma
	cfg.PartyFrame	= true							-- show party frame
	cfg.RaidFrame	= true							-- show raid frame

	-- Plugins
	cfg.EMR			= true							-- enable to display energy mana regeneration rule
	cfg.Totems		= true							-- enable to display shaman totem icon
	cfg.showXpRep	= true							-- show xp/rep display on mouseover (player)
	cfg.AuraWatch	= true							-- enable for watch specific auras on raid units
	cfg.RaidDebuffs	= true							-- enable important debuff icons to show on raid units

	cfg.Fader = {
		enable 		= true,							-- enable unit frame fader
		FadeIn 		= 1.0,							-- seconds of fade-in
		FadeOut 	= 2.5,							-- seconds of fade-out
		MaxAlpha 	= 1.0,							-- faded-in alpha
		MinAlpha 	= 0.0,							-- faded-out alpha
	}

	cfg.Aurabar = {									-- display buffs/debuffs as status bars
		enable 		= true,							-- enable Aurabar
		color		= true,							-- color buffs by caster class 
		width 		= 150,							-- bar width
		height 		= 5,							-- bar height
		num 		= 8,							-- icon bar amount
		iconSize 	= 20,							-- icon size
	}

---------------------------
-- Unit Frames Size --
---------------------------
	cfg.UFS = {										-- set unit size health/power width/height
		Prime	= { w=  175,  h=  35,  hh=  28,  ph=  3 },
		Pet 	= { w=  120,  h=  25,  hh=  22,  ph=  2 },
		TT 		= { w=  125,  h=  30,  hh=  24,  ph=  2 },
		Tank 	= { w=  120,  h=  25,  hh=  22,  ph=  2 },
		Party 	= { w=  150,  h=  30,  hh=  25,  ph=  2 },
		Raid 	= { w=   75,  h=  36,  hh=  36,  ph=  2 },
	}

---------------------------
-- Unit Frames Position --
---------------------------
	cfg.UFP = {										-- set unit frames position
		Player 	= { 'TOPLEFT',		'UIParent',				'CENTER',		-370,		-180 },
		Pet 	= { 'BOTTOMLEFT',	'oUF_NihlathakPlayer',	'TOPLEFT',		   0,		  12 },
 		Target 	= { 'TOPRIGHT',		'UIParent',				'CENTER',		 370,		-180 },
		TT 		= { 'BOTTOM',		'UIParent',            	'CENTER',		   0,		-200 },
		Tank 	= { 'TOPRIGHT',		'UIParent',            	'RIGHT',		 -30,		 180 },
		Party 	= { 'TOPLEFT',		'UIParent',            	'CENTER',	  -570.5,         90 },
		Raid 	= { 'TOPLEFT',		'UIParent',            	'LEFT',			   8,      125.1 },
	}

-----------------------------
-- Hand over --
-----------------------------

ns.cfg = cfg	-- don't touch this ...