local _, ns = ...
local cfg = ns.cfg
local filter = ns.filter
local aurabar = CreateFrame('Frame')

-- Lua APIs
local unpack = unpack
local huge   = math.huge
local tsort  = table.sort

-- WoW APIs
local CreateFrame = CreateFrame
local GetTime     = GetTime
local UnitAura    = UnitAura
local UnitClass   = UnitClass

-- Register Libs
local LCD = LibStub('LibClassicDurations', true)

local CreateAuraTimer = function(self, elapsed)
    if (self.expiration) then
        self.expiration = self.expiration - elapsed
        self.bar:SetValue(self.expiration)
		-- set text color
		if (self.expiration > 0 and self.expiration < cfg.auraTimer) then
			self.time:SetFormattedText(FormatTime(self.expiration))

			if (self.expiration < 5) then
                self.time:SetTextColor(1, .3, .3)
            elseif (self.expiration < 10) then
                self.time:SetTextColor(1, 1, 0)
			else
				self.time:SetTextColor(1, 1, 1)
			end
        else
            self:SetScript('OnUpdate', nil)
			self.time:SetText()
        end
    end
end

local PostCreateIcon = function(auras, button)
    auras.disableMouse          = true      -- disables tooltip
    button.cd.noCooldownCount   = true	    -- hide CooldownCount
    
    button.icon:SetTexCoord(.08, .92, .08, .92)
    
    auras.overlay = CreateFrame('Frame', nil, button, 'BackdropTemplate')
    auras.overlay:SetPoint('TOPLEFT', button, -1, 1)
    auras.overlay:SetPoint('BOTTOMRIGHT', button, 1, -1)
    auras.overlay:SetBackdrop(cfg.pixelBD)
    auras.overlay:SetBackdropColor(unpack(cfg.maincolor))
    auras.overlay:SetBackdropBorderColor(unpack(cfg.maincolor))
    auras.overlay:SetFrameLevel(0)

    button.bar = CreateFrame('StatusBar', nil, button)
    button.bar:SetStatusBarTexture(cfg.Normal)
    button.bar:SetPoint('BOTTOMLEFT', button, 'BOTTOMRIGHT', 4, 0)
    button.bar:SetSize(cfg.Aurabar.width, cfg.Aurabar.height)
    
    button.bar.spark = button.bar:CreateTexture(nil, 'OVERLAY')
    button.bar.spark:SetTexture([[Interface\CastingBar\UI-CastingBar-Spark]])
    button.bar.spark:SetPoint('CENTER', button.bar:GetStatusBarTexture(), 'RIGHT')
	button.bar.spark:SetSize(8, 20)
	button.bar.spark:SetBlendMode('ADD')

    button.bar.bg = CreateFrame('StatusBar', nil, button.bar, 'BackdropTemplate')
    button.bar.bg:SetPoint('TOPLEFT', button.bar, -1, 1)
    button.bar.bg:SetPoint('BOTTOMRIGHT', button.bar, 1, -1)
    button.bar.bg:SetBackdrop(cfg.pixelBD)
    button.bar.bg:SetBackdropColor(.2, .2, .2, .3)
    button.bar.bg:SetBackdropBorderColor(unpack(cfg.maincolor))
    button.bar.bg:SetFrameLevel(0)
    
    button.name = button.bar:CreateFontString(nil, 'OVERLAY')
    button.name:SetFont(cfg.NameFont, cfg.SmallFS, cfg.FontF)
    button.name:SetPoint('BOTTOMLEFT', button.bar, 'TOPLEFT', 2, 0)
    button.name:SetWidth(button.bar:GetWidth() * 0.8)
    button.name:SetJustifyH('LEFT')
    button.name:SetWordWrap(false)
    
    button.time = button.bar:CreateFontString(nil, 'OVERLAY')
    button.time:SetFont(cfg.PlugFont, cfg.SmallFS, cfg.FontF)
    button.time:SetPoint('LEFT', button.name, 'RIGHT', 5, 0)
    button.time:SetJustifyH('LEFT')
    
    button.count:SetFont(cfg.PlugFont, cfg.SmallFS, cfg.FontF)
    button.count:SetPoint('CENTER', button)
    button.count:SetTextColor(unpack(cfg.countcolor))
end

local PostUpdateIcon = function(auras, unit, button, index, _, duration, expiration, debuffType)
    local name, _, _, _, _, _, caster = LCD:UnitAura(unit, index, button.filter)
    button.name:SetText(name)

    if (duration and duration > 0) then
        button.expiration = expiration - GetTime()
        button:SetScript('OnUpdate', CreateAuraTimer)

        button.bar:SetMinMaxValues(0, duration)
        button.bar.spark:Show()
        -- set icon saturation
        if (button.isPlayer) then
            button.icon:SetDesaturated(false)
        else
            button.icon:SetDesaturated(true)
        end
        -- set bar color
        if (button.isDebuff) then
            local color = _G.DebuffTypeColor[debuffType or 'none']
            button.bar:SetStatusBarColor(color.r, color.g, color.b, .7)
        else
            if cfg.Aurabar.color then
                local _, class = UnitClass(caster or unit)
                local color = _G.RAID_CLASS_COLORS[class]
                button.bar:SetStatusBarColor(color.r, color.g, color.b, .7)
            else
                button.bar:SetStatusBarColor(.15, .85, 1, .7)
            end
        end
    else
        button.time:SetText()
        button.expiration = huge
        
        button.bar:SetStatusBarColor(.2, .2, .2, .3)
        button.bar.spark:Hide()
    end
end

local SortAuras = function(a, b)
	if (a:IsShown() and b:IsShown()) then
		return a.expiration < b.expiration
	else
		return a:IsShown()
	end
end

local PreSetPosition = function(auras)
	tsort(auras, SortAuras)
	return 1, auras.createdIcons
end

aurabar.Filter = function(auras, unit, button, name, _, _, _, _, _, _, _, _, spellID)
    if (not name) then return end
    if filter.Auras[spellID] then
        -- 'Shadow Vulnerability' Visible only for Warlock
        if (spellID == 17800) then
            if (select(2, UnitClass('player')) == 'WARLOCK') then
                return true
            else
                return
            end
        end
        return true
    end
end

aurabar.CreateBar = function(self)
    local aurabar = CreateFrame('Frame', nil, self)
    aurabar.numTotal = cfg.Aurabar.num
    aurabar.size = cfg.Aurabar.iconSize
    aurabar.spacing = 4
    aurabar:SetSize(cfg.Aurabar.iconSize, (cfg.Aurabar.iconSize + aurabar.spacing) * cfg.Aurabar.num)
    aurabar.PreSetPosition = PreSetPosition
    aurabar.PostCreateIcon = PostCreateIcon
    aurabar.PostUpdateIcon = PostUpdateIcon
    
    return aurabar
end

-----------------------------
-- Hand over --
-----------------------------
ns.aurabar = aurabar -- don't touch this ...