﻿local _, ns = ...
local oUF = ns.oUF

-- Lua APIs
local unpack 	= unpack
local pairs 	= pairs
local floor		= math.floor
local format	= string.format

-- WoW APIs
local UnitXP            = UnitXP
local UnitXPMax         = UnitXPMax
local UnitClass   		= UnitClass
local UnitLevel         = UnitLevel
local UnitHealth        = UnitHealth
local UnitHealthMax     = UnitHealthMax
local UnitPower         = UnitPower
local UnitPowerMax      = UnitPowerMax
local UnitIsDead 		= UnitIsDead
local UnitIsGhost 		= UnitIsGhost
local UnitReaction      = UnitReaction
local UnitIsPlayer      = UnitIsPlayer
local UnitIsTapDenied   = UnitIsTapDenied
local UnitIsConnected 	= UnitIsConnected
local UnitIsFeignDeath  = UnitIsFeignDeath
local UnitIsDeadOrGhost = UnitIsDeadOrGhost

local utf8sub = function(string, i, dots)
    local bytes = string:len()
    if (bytes <= i) then
        return string
    else
        local len, pos = 0, 1
        while (pos <= bytes) do
            len = len + 1
            local c = string:byte(pos)
            if (c > 240) then
                pos = pos + 4
            elseif (c > 225) then
                pos = pos + 3
            elseif (c > 192) then
                pos = pos + 2
            else
                pos = pos + 1
            end
            if (len == i) then break end
        end
        
        if (len == i and pos <= bytes) then
            return string:sub(1, pos - 1) .. (dots and '...' or '')
        else
            return string
        end
    end
end

local Hex = function(r, g, b)
    if r then
        if (type(r) == 'table') then
            if (r.r) then
                r, g, b = r.r, r.g, r.b
            else
                r, g, b = unpack(r)
            end
        end
        return ('|cff%02x%02x%02x'):format(r * 255, g * 255, b * 255)
    end
end

-----------------
-- custom tags --
-----------------
oUF.Tags.Methods['hp'] = function(unit)
    return UnitHealth(unit) .. ' - ' .. UnitHealthMax(unit)
end
oUF.Tags.Events['hp'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_HEALTH_FREQUENT UNIT_MAXHEALTH'

oUF.Tags.Methods['curhp'] = function(unit)
    return ShortValue(UnitHealth(unit))
end
oUF.Tags.Events['curhp'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_HEALTH_FREQUENT UNIT_MAXHEALTH'

oUF.Tags.Methods['hpp'] = function(unit)
    local perhp = _TAGS['perhp'](unit)
    
    if (UnitIsDead(unit)) then
        return '|cffFF3333RIP|r'
    elseif (UnitIsGhost(unit)) then
        return '|cffFF3333GHO|r'
    elseif (not UnitIsConnected(unit)) then
        return '|cffFF3333OFF|r'
    else
        return perhp .. '|cff0090FF%|r'
    end
end
oUF.Tags.Events['hpp'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_HEALTH_FREQUENT UNIT_MAXHEALTH'

oUF.Tags.Methods['pp'] = function(unit)
    return UnitPower(unit) .. ' - ' .. UnitPowerMax(unit)
end
oUF.Tags.Events['pp'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_POWER_UPDATE UNIT_MAXPOWER'

oUF.Tags.Methods['curpp'] = function(unit)
    return ShortValue(UnitPower(unit))
end
oUF.Tags.Events['curpp'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_POWER_UPDATE UNIT_MAXPOWER'

oUF.Tags.Methods['namecolor'] = function(unit)
    local _, class = UnitClass(unit)
    local reaction = UnitReaction(unit, 'player')
    
    if (UnitIsDeadOrGhost(unit) and not UnitIsFeignDeath(unit)) then
        return '|cffA0A0A0'
    elseif (UnitIsTapDenied(unit)) then
        return Hex(oUF.colors.tapped)
    elseif (UnitIsPlayer(unit)) then
        return Hex(oUF.colors.class[class])
    elseif ((unit == 'pet') or reaction) then
        return Hex(oUF.colors.reaction[reaction])
    else
        return Hex(1, 1, 1)
    end
end
oUF.Tags.Events['namecolor'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_NAME_UPDATE UNIT_HEALTH_FREQUENT UNIT_MAXHEALTH'

oUF.Tags.Methods['raidmissinghpname'] = function(unit, realUnit)
    local name = _TAGS['name'](unit, realUnit)
    local missinghp = _TAGS['missinghp'](unit)
    local c, m = UnitHealth(unit), UnitHealthMax(unit)

    if (UnitIsDead(unit) and not UnitIsFeignDeath(unit)) then
        return 'RIP'
    elseif (UnitIsFeignDeath(unit)) then
        return 'F.D'
    elseif (UnitIsGhost(unit)) then
        return 'GHO'
    elseif (c < m and UnitIsConnected(unit)) then
        return '-' .. ShortValue(missinghp)
    else
        return utf8sub(name, 4, false)
    end
end
oUF.Tags.Events['raidmissinghpname'] = 'UNIT_CONNECTION UNIT_FLAGS UNIT_NAME_UPDATE UNIT_HEALTH_FREQUENT UNIT_MAXHEALTH'

-- xp/rep
oUF.Tags.Methods['Exp'] = function(unit)
    if UnitLevel('player') ~= MAX_PLAYER_LEVEL then
        local perc = floor(UnitXP('player') / UnitXPMax('player') * 100 + 0.5)

        if (GetXPExhaustion()) then
            return ('XP: %s (%.1f%%)/%s (%.1f%% R)'):format(ShortValue(UnitXP('player')), perc, ShortValue(UnitXPMax('player')), (GetXPExhaustion() or 0) / UnitXPMax('player') * 100)
        else
            return ('XP: %s (%.1f%%)/%s'):format(ShortValue(UnitXP('player')), perc, ShortValue(UnitXPMax('player')))
        end
    else
        return
    end
end
oUF.Tags.Events['Exp'] = 'PLAYER_XP_UPDATE UPDATE_EXHAUSTION UNIT_LEVEL'

oUF.Tags.Methods['Rep'] = function(unit)
    local name, standingID, min, max, cur = GetWatchedFactionInfo()

    if (name) then
        local color = oUF.colors.reaction[standingID]
        return ('|cff%.2x%.2x%.2x%s: %s/%s|r'):format(color[1] * 255, color[2] * 255, color[3] * 255, name, cur - min, max - min)
    else
        return
    end
end
oUF.Tags.Events['Rep'] = 'UPDATE_FACTION CHAT_MSG_COMBAT_FACTION_CHANGE'

-- We need this for oUF to update certain tags properly
for _, event in pairs({'UPDATE_FACTION', 'CHAT_MSG_COMBAT_FACTION_CHANGE'}) do
    oUF.Tags.SharedEvents[event] = true
end