--[[
# Element: AFK Indicator

Handles the visibility and updating of an Indicator based on the unit flag is AFK.

## Widget

AfkIndicator - A `Texture` used to display if the unit flag is AFK.

## Notes

A default texture will be applied if the widget is a Texture and doesn't have a texture or a color set.

## Examples

    -- Position and size
    local AfkIndicator = self:CreateTexture(nil, 'OVERLAY')
    AfkIndicator:SetSize(16, 16)
    AfkIndicator:SetPoint('TOPRIGHT', self)

    -- Register it with oUF
    self.AfkIndicator = AfkIndicator
--]]

local _, ns = ...
local oUF = ns.oUF

local function Update(self, event, unit)
	if(self.unit ~= unit) then return end
	local element = self.AfkIndicator
	
	local isAFK = UnitIsAFK(unit)
	if(isAFK) then
		element:Show()
	else
		element:Hide()
	end

	if(element.PostUpdate) then
		return element:PostUpdate(isAFK)
	end
end

local function Path(self, ...)
	return (self.AfkIndicator.Override or Update) (self, ...)
end

local function ForceUpdate(element)
	return Path(element.__owner, 'ForceUpdate')
end

local function Enable(self, unit)
	local element = self.AfkIndicator
	if(element) then
		element.__owner = self
		element.ForceUpdate = ForceUpdate

		self:RegisterEvent('UNIT_FLAGS', Path)
		self:RegisterEvent('PLAYER_FLAGS_CHANGED', Path)

		if(element:IsObjectType('Texture') and not element:GetTexture()) then
			element:SetTexture([[Interface\FriendsFrame\StatusIcon-Away]])
		end

		return true
	end
end

local function Disable(self)
	local element = self.AfkIndicator
	if(element) then
		element:Hide()

		self:UnregisterEvent('UNIT_FLAGS', Path)
		self:UnregisterEvent('PLAYER_FLAGS_CHANGED', Path)
	end
end

oUF:AddElement('AfkIndicator', Path, Enable, Disable)