--[[
# Element: Hunter's FeignDeath Indicator

Handles the visibility and updating of an Indicator based on the unit is feigning death.

## Widget

FeignIndicator - A `Texture` used to display if the unit is feigning death.

## Notes

A default texture will be applied if the widget is a Texture and doesn't have a texture or a color set.

## Examples

    -- Position and size
    local FeignIndicator = self:CreateTexture(nil, 'OVERLAY')
    FeignIndicator:SetSize(16, 16)
    FeignIndicator:SetPoint('CENTER', self)

    -- Register it with oUF
    self.FeignIndicator = FeignIndicator
--]]

local _, ns = ...
local oUF = ns.oUF

local function Update(self, event, unit)
	if(self.unit ~= unit) then return end
	local element = self.FeignIndicator
	
	local isFeign = UnitIsFeignDeath(unit)
	if(isFeign) then
		element:Show()
	else
		element:Hide()
	end

	if(element.PostUpdate) then
		return element:PostUpdate(isFeign)
	end
end

local function Path(self, ...)
	return (self.FeignIndicator.Override or Update) (self, ...)
end

local function ForceUpdate(element)
	return Path(element.__owner, 'ForceUpdate')
end

local function Enable(self, unit)
	local element = self.FeignIndicator
	if(element) then
		element.__owner = self
		element.ForceUpdate = ForceUpdate

		self:RegisterEvent('UNIT_FLAGS', Path)
		self:RegisterEvent('UNIT_AURA', Path)

		if(element:IsObjectType('Texture') and not element:GetTexture()) then
			element:SetTexture([[Interface\Icons\Ability_Rogue_FeignDeath]])
			element:SetTexCoord(.08, .92, .08, .92)
		end

		return true
	end
end

local function Disable(self)
	local element = self.FeignIndicator
	if(element) then
		element:Hide()

		self:UnregisterEvent('UNIT_FLAGS', Path)
		self:UnregisterEvent('UNIT_AURA', Path)
	end
end

oUF:AddElement('FeignIndicator', Path, Enable, Disable)