----------------------------------------------------------------------------------------
--	Based on oUF_DebuffHighlight(by Ammo)
----------------------------------------------------------------------------------------
local _, ns = ...
local oUF = ns.oUF

-- WoW APIs
local IsSpellKnown	= IsSpellKnown
local UnitAura 		= UnitAura
local UnitClass		= UnitClass
local UnitCanAssist = UnitCanAssist

local playerClass = select(2, UnitClass('player'))
local CanDispel = {
	PRIEST  = { Magic  = true, 	Disease = true  },
    SHAMAN  = { Poison = true, 	Disease = true  },
    PALADIN = { Magic  = true,	Poison  = true,	Disease = true	},
    DRUID   = { Curse  = true,	Poison  = true	},
    MAGE    = { Curse  = true	},
	WARLOCK = {},
}
local DispelList = CanDispel[playerClass] or {}

local DevourMagic = {
	[19505] = 'Rank 1',
	[19731] = 'Rank 2',
	[19734] = 'Rank 3',
	[19736] = 'Rank 4',
	[27276] = 'Rank 5',
	[27277] = 'Rank 6',
}

local BlackList = {
	[6136] 	= true, -- Chilled (Frost Armor) -- 冰冻 (Frost Armor)
	[7321] 	= true, -- Chilled (Ice Armor)	 -- 冰冻 (冰甲术)
	[12579]	= true, -- Winter's Chill		 -- 深冬之寒
	[13810]	= true, -- Frost Trap Aura		 -- 冰霜陷阱光环
	[22599]	= true, -- Fire Vulnerability	 -- 痛苦诅咒
}

local function CheckPetSpells()
	for spellID in next, DevourMagic do
		if IsSpellKnown(spellID, true) then
			return true
		end
	end
end

local function GetDebuffType(unit, filter)
	if not unit or not UnitCanAssist('player', unit) then return end
	local i = 1
	while true do
		local _, texture, _, debuffType, _, _, _, _, _, spellID = UnitAura(unit, i, 'HARMFUL')
		if not texture then break end
		if debuffType and (not filter or DispelList[debuffType]) and not BlackList[spellID] then
			return debuffType, texture
		end
		i = i + 1
	end
end

local function Update(self, event, unit)
	if unit ~= self.unit then return end

	local debuffType = GetDebuffType(unit, self.DebuffHighlightFilter)
	if debuffType then
		local color = DebuffTypeColor[debuffType]
		if self.DebuffHighlightBorder then
			self.DebuffHighlightBorder:Show()
			self.DebuffHighlightBorder:SetBackdropBorderColor(color.r, color.g, color.b)
		elseif self.DebuffHighlight then
			self.DebuffHighlight:Show()
			self.DebuffHighlight:SetVertexColor(color.r, color.g, color.b)
		end
	else
		if self.DebuffHighlightBorder then
			self.DebuffHighlightBorder:Hide()
		elseif self.DebuffHighlight then
			self.DebuffHighlight:Hide()
		end
	end
end

local function CheckPetDispel(self, event, arg1)
	if event == 'UNIT_PET' then
		if arg1 == 'player' and playerClass == 'WARLOCK' then
			DispelList.Magic = CheckPetSpells()
		end
	else
		return
	end
	
	Update(self, event, self.unit)
end

local function Enable(self)
	-- if we're not highlighting this unit return
	if not self.DebuffHighlightBorder and not self.DebuffHighlight then
		return
	end
	-- if we're filtering highlights and we're not of the dispelling type, return
	if self.DebuffHighlightFilter and not CanDispel[playerClass] then
		return
	end

	self:RegisterEvent('UNIT_AURA', Update)
	self:RegisterEvent('PLAYER_LOGIN', CheckPetDispel, true)
	self:RegisterEvent('UNIT_PET', CheckPetDispel, true)

	return true
end

local function Disable(self)
	self:UnregisterEvent('UNIT_AURA', Update)
	self:UnregisterEvent('PLAYER_LOGIN', CheckPetDispel)
	self:UnregisterEvent('UNIT_PET', CheckPetDispel)

	if self.DebuffHighlightBorder then
		self.DebuffHighlightBorder:Hide()
	end

	if self.DebuffHighlight then
		self.DebuffHighlight:Hide()
	end
end

oUF:AddElement('DebuffHighlight', Update, Enable, Disable)