----------------------------------------------------------------------------------------
--	Based on oUF_Fader(by p3lim)
----------------------------------------------------------------------------------------
local _, ns = ...
local oUF = ns.oUF

-- WoW APIs
local CreateFrame 		= CreateFrame
local IsStealthed       = IsStealthed
local GetMouseFocus     = GetMouseFocus
local UnitExists        = UnitExists
local UnitHealth        = UnitHealth
local UnitHealthMax     = UnitHealthMax
local UnitPower         = UnitPower
local UnitPowerMax      = UnitPowerMax
local UnitPowerType     = UnitPowerType
local UnitCastingInfo   = UnitCastingInfo
local UnitChannelInfo   = UnitChannelInfo
local UnitAffectingCombat   = UnitAffectingCombat

-- BlizzardInterfaceCode Frame fading --
local frameFadeManager = CreateFrame('FRAME')

local function UIFrameFade(frame, fadeInfo)
    if (not frame) then
		return;
	end
	if ( not fadeInfo.mode ) then
		fadeInfo.mode = 'IN';
	end
	local alpha;
	if ( fadeInfo.mode == 'IN' ) then
		if ( not fadeInfo.startAlpha ) then
			fadeInfo.startAlpha = 0;
		end
		if ( not fadeInfo.endAlpha ) then
			fadeInfo.endAlpha = 1.0;
		end
		alpha = 0;
	elseif ( fadeInfo.mode == 'OUT' ) then
		if ( not fadeInfo.startAlpha ) then
			fadeInfo.startAlpha = 1.0;
		end
		if ( not fadeInfo.endAlpha ) then
			fadeInfo.endAlpha = 0;
		end
		alpha = 1.0;
	end
	frame:SetAlpha(fadeInfo.startAlpha);
	frame.fadeInfo = fadeInfo;

    tinsert(FADEFRAMES, frame)
    frameFadeManager:SetScript('OnUpdate', UIFrameFade_OnUpdate);
end

-- Convenience function to do a simple fade in
local function UIFrameFadeIn(frame, timeToFade, startAlpha, endAlpha)
    local fadeInfo = {};
    fadeInfo.mode = 'IN';
    fadeInfo.timeToFade = timeToFade;
    fadeInfo.startAlpha = startAlpha;
    fadeInfo.endAlpha = endAlpha;
    UIFrameFade(frame, fadeInfo);
end

-- Convenience function to do a simple fade out
local function UIFrameFadeOut(frame, timeToFade, startAlpha, endAlpha)
    local fadeInfo = {};
    fadeInfo.mode = 'OUT';
    fadeInfo.timeToFade = timeToFade;
    fadeInfo.startAlpha = startAlpha;
    fadeInfo.endAlpha = endAlpha;
    UIFrameFade(frame, fadeInfo);
end

-- oUF_Fader
local function Update(self, event)
    local unit = self.unit
    local FadeIn = self.FadeIn
    local FadeOut = self.FadeOut
    local _, powerType = UnitPowerType(unit)

    local Conditions =
    (UnitAffectingCombat(unit)) or
    (UnitExists('target')) or
    (UnitExists(unit..'target')) or
    (UnitHealth(unit) < UnitHealthMax(unit)) or
    ((self.Castbar) and (UnitCastingInfo(unit) or UnitChannelInfo(unit))) or
    ((powerType == 'RAGE' or powerType == 'RUNIC_POWER') and (UnitPower(unit) > 0)) or
    ((powerType ~= 'RAGE') and (powerType ~= 'RUNIC_POWER') and (UnitPower(unit) < UnitPowerMax(unit))) or
    (GetMouseFocus() == self) or (IsStealthed())

    if (Conditions) then
        if (FadeIn) then
            UIFrameFadeIn(self, FadeIn, self:GetAlpha(), self.MaxAlpha or 1)
        end
    else
        if (FadeOut) then
            UIFrameFadeOut(self, FadeOut, self:GetAlpha(), self.MinAlpha or 0.4)
        end
    end
end

local function Enable(self)
    local Fader = self.Fader
    if (Fader) then

        self:HookScript('OnEnter', Update)
        self:HookScript('OnLeave', Update)
        self:RegisterEvent('UNIT_FLAGS', Update)
        self:RegisterEvent('UNIT_TARGET', Update)
        self:RegisterEvent('UNIT_HEALTH_FREQUENT', Update)
        self:RegisterEvent('UNIT_MAXHEALTH', Update)
        self:RegisterEvent('UNIT_MAXPOWER', Update)
        self:RegisterEvent('UNIT_POWER_UPDATE', Update)
        self:RegisterEvent('UPDATE_STEALTH', Update, true)
        self:RegisterEvent('PLAYER_REGEN_ENABLED', Update, true)
        self:RegisterEvent('PLAYER_REGEN_DISABLED', Update, true)
        self:RegisterEvent('PLAYER_TARGET_CHANGED', Update, true)

        if (self.Castbar) then
            self:RegisterEvent('UNIT_SPELLCAST_START', Update)
            self:RegisterEvent('UNIT_SPELLCAST_STOP', Update)
            self:RegisterEvent('UNIT_SPELLCAST_CHANNEL_START', Update)
            self:RegisterEvent('UNIT_SPELLCAST_CHANNEL_STOP', Update)
        end

        return true
    end
end

local function Disable(self)
    local Fader = self.Fader
    if (Fader) then

        self:UnregisterEvent('UNIT_FLAGS', Update)
        self:UnregisterEvent('UNIT_TARGET', Update)
        self:UnregisterEvent('UNIT_HEALTH_FREQUENT', Update)
        self:UnregisterEvent('UNIT_MAXHEALTH', Update)
        self:UnregisterEvent('UNIT_MAXPOWER', Update)
        self:UnregisterEvent('UNIT_POWER_UPDATE', Update)
        self:UnregisterEvent('UPDATE_STEALTH', Update)
        self:UnregisterEvent('PLAYER_REGEN_ENABLED', Update)
        self:UnregisterEvent('PLAYER_REGEN_DISABLED', Update)
        self:UnregisterEvent('PLAYER_TARGET_CHANGED', Update)

        if (self.Castbar) then
            self:UnregisterEvent('UNIT_SPELLCAST_START', Update)
            self:UnregisterEvent('UNIT_SPELLCAST_STOP', Update)
            self:UnregisterEvent('UNIT_SPELLCAST_CHANNEL_START', Update)
            self:UnregisterEvent('UNIT_SPELLCAST_CHANNEL_STOP', Update)
        end
    end
end

oUF:AddElement('Fader', Update, Enable, Disable)