local _, ns = ...
local oUF = ns.oUF
local addon = {}

-- Lua APIs
local type  = type
local pairs = pairs

-- WoW APIs
local GetTime 		= GetTime
local GetSpellInfo 	= GetSpellInfo
local UnitAura 		= UnitAura
local UnitClass     = UnitClass
local UnitIsUnit    = UnitIsUnit
local UnitIsCharmed = UnitIsCharmed
local UnitCanAttack = UnitCanAttack

-- Register Libs
local LCD = LibStub('LibClassicDurations', true)

ns.oUF_RaidDebuffs = addon
_G.oUF_RaidDebuffs = ns.oUF_RaidDebuffs

if not _G.oUF_RaidDebuffs then
    _G.oUF_RaidDebuffs = addon
end

local debuff_data = {}
addon.DebuffData = debuff_data
addon.ShowDispelableDebuff = true
addon.FilterDispelableDebuff = true
addon.MatchBySpellName = false
addon.priority = 10

-- enable to force show raid debuffs icon
local forceShow = false
local forceShow_Spells = {118, 122, 172, 348, 980, 2637, 5782, 6789}
local forceShow_deType = {'none', 'Magic', 'Curse', 'Poison', 'Disease'}

local function add(spell, priority, stackThreshold)
    if addon.MatchBySpellName and type(spell) == 'number' then
        spell = GetSpellInfo(spell)
    end
    
    if (spell) then
        debuff_data[spell] = {
            priority = (addon.priority + priority),
            stackThreshold = (stackThreshold or 0),
        }
    end
end

function addon:RegisterDebuffs(t)
    for spell, value in pairs(t) do
        if type(t[spell]) == 'boolean' then
            local oldValue = t[spell]
            t[spell] = { enable = oldValue, priority = 0, stackThreshold = 0 }
        else
            if t[spell].enable then
                add(spell, t[spell].priority, t[spell].stackThreshold)
            end
        end
    end
end

local blackList = {
    [6136] 	= true, -- Chilled (Frost Armor) -- 冰冻 (Frost Armor)
	[7321] 	= true, -- Chilled (Ice Armor)	 -- 冰冻 (冰甲术)
	[12579]	= true, -- Winter's Chill		 -- 深冬之寒
}

local DispelPriority = {
	Magic   = 4,
	Curse   = 3,
	Disease = 2,
	Poison  = 1,
}

local DispelColor = {
	Magic   = {	.2,	.6,	1 },
	Curse   = { .6,  0, 1 },
    Disease = { .6, .4, 0 },
    Poison  = {  0, .6, 0 },
    none    = {  1,  0, 0 },
}

local DispelFilter
do
    local DispelClasses = {
        PRIEST  = { Magic  = true, 	Disease = true  },
        SHAMAN  = { Poison = true, 	Disease = true  },
        PALADIN = { Magic  = true,  Poison  = true, Disease = true	},
        DRUID   = { Curse  = true,	Poison  = true	},
        MAGE    = { Curse  = true	},
    }
    DispelFilter = DispelClasses[select(2, UnitClass('player'))] or {}
end

local function CreateRDTimer(self, elapsed)
    self.elapsed = (self.elapsed or 0) + elapsed
    if (self.elapsed >= 0.1) then
        local timeLeft = self.expiration - GetTime()
        -- set text color
        if (timeLeft > 0) then
            self.time:SetFormattedText(FormatTime(timeLeft))
            if (timeLeft < 5) then
                self.time:SetTextColor(1, .3, .3)
            else
                self.time:SetTextColor(.1, .9, 1)
            end
        else
            self:SetScript('OnUpdate', nil)
            self.time:Hide()
        end

        self.elapsed = 0
    end
end

local function UpdateDebuff(self, name, icon, count, debuffType, duration, expiration, spellID, stackThreshold)
    local rd = self.RaidDebuffs
    
    if name and (count >= stackThreshold) then
        rd.icon:SetTexture(icon)
        rd.icon:Show()
        rd.duration = duration
        
        if rd.count then
            if count and (count > 1) then
                rd.count:Show()
                rd.count:SetText(count)
            else
                rd.count:Hide()
                rd.count:SetText('')
            end
        end
        
        if rd.time then
            if duration and (duration > 0) then
                rd.time:Show()
                rd.expiration = expiration
                rd:SetScript('OnUpdate', CreateRDTimer)
            else
                rd.time:Hide()
            end
        end
        
        if rd.cd then
            if duration and (duration > 0) then
                rd.cd:Show()
                rd.cd:SetCooldown(expiration - duration, duration)
            else
                rd.cd:Hide()
            end
        end
        
        local c = DispelColor[debuffType] or DispelColor.none
        rd:SetBackdropBorderColor(c[1], c[2], c[3])
        
        rd:Show()
    else
        rd:Hide()
    end
end

local function Update(self, event, unit)
    if unit ~= self.unit then return end
    local _name, _icon, _count, _dtype, _duration, _expiration, _spellID
    local _stackThreshold, _priority, priority = 0, 0, 0
    
    --store if the unit its charmed, mind controlled units (Imperial Vizier Zor'lok: Convert)
    local isCharmed = UnitIsCharmed(unit)
    
    --store if we cand attack that unit, if its so the unit its hostile (Amber-Shaper Un'sok: Reshape Life)
    local canAttack = UnitCanAttack('player', unit)
    
    for i = 1, 40 do
		local name, icon, count, debuffType, duration, expiration, caster, _, _, spellID = UnitAura(unit, i, 'HARMFUL')
		if (not name) then break end

		local durationNew, expirationNew = LCD:GetAuraDurationByUnit(unit, spellID, caster, name)
		if (duration == 0 and durationNew) then
			duration = durationNew
			expiration = expirationNew
		end

        --we coudln't Dispel if the unit its charmed, or its not friendly
        if addon.ShowDispelableDebuff and (self.RaidDebuffs.showDispelableDebuff ~= false) and debuffType and (not isCharmed) and (not canAttack) then
            if addon.FilterDispelableDebuff then
                DispelPriority[debuffType] = (DispelPriority[debuffType] or 0) + addon.priority --Make Dispel buffs on top of Boss Debuffs
                priority = DispelFilter[debuffType] and DispelPriority[debuffType] or 0
            else
                priority = DispelPriority[debuffType] or 0
            end
            if priority > _priority then
                _priority, _name, _icon, _count, _dtype, _duration, _expiration, _spellID = priority, name, icon, count, debuffType, duration, expiration, spellID
            end
        end
        
        local debuff
        if self.RaidDebuffs.onlyMatchSpellID then
            debuff = debuff_data[spellID]
        else
            if debuff_data[spellID] then
                debuff = debuff_data[spellID]
            else
                debuff = debuff_data[name]
            end
        end
        
        priority = debuff and debuff.priority
        if priority and not blackList[spellID] and (priority > _priority) then
            _priority, _name, _icon, _count, _dtype, _duration, _expiration, _spellID = priority, name, icon, count, debuffType, duration, expiration, spellID
        end
    end
    
    if forceShow then
        _spellID = forceShow_Spells[random(1, #forceShow_Spells)]
        _name, _, _icon = GetSpellInfo(_spellID)
        _count, _dtype, _duration, _expiration, _stackThreshold = 5, forceShow_deType[random(1, #forceShow_deType)], 24, GetTime() + 24, 0
    end
    
    if _name then
        _stackThreshold = debuff_data[addon.MatchBySpellName and _name or _spellID] and debuff_data[addon.MatchBySpellName and _name or _spellID].stackThreshold or _stackThreshold
    end
    
    UpdateDebuff(self, _name, _icon, _count, _dtype, _duration, _expiration, _spellID, _stackThreshold)

    --Reset the DispelPriority
	DispelPriority.Magic 	= 4
	DispelPriority.Curse 	= 3
	DispelPriority.Disease 	= 2
	DispelPriority.Poison 	= 1
end

local function Enable(self)
    if (self.RaidDebuffs) then
        self:RegisterEvent('UNIT_CONNECTION', Update)
        self:RegisterEvent('UNIT_AURA', Update)

        return true
    end
end

local function Disable(self)
    if (self.RaidDebuffs) then
        self:UnregisterEvent('UNIT_CONNECTION', Update)
        self:UnregisterEvent('UNIT_AURA', Update)
        
        self.RaidDebuffs:Hide()
    end
end

oUF:AddElement('RaidDebuffs', Update, Enable, Disable)